spindry.Spinner
===============

.. currentmodule:: spindry

.. autoclass:: Spinner
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Spinner.compute_potential
      ~Spinner.get_conformers
      ~Spinner.get_final_conformer
   
   

   
   
   